[Mesa-stable] [PATCH] radeon/uvd: don't expose HEVC on old UVD hw

Alex Deucher alexdeucher at gmail.com
Thu Oct 22 09:27:49 PDT 2015


The section for UVD 2 and older was not updated
when HEVC support was added. Reported by Kano
on irc.

Signed-off-by: Alex Deucher <alexander.deucher at amd.com>
Cc: mesa-stable at lists.freedesktop.org
---
 src/gallium/drivers/radeon/radeon_video.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/src/gallium/drivers/radeon/radeon_video.c b/src/gallium/drivers/radeon/radeon_video.c
index 3a1834b..722f446 100644
--- a/src/gallium/drivers/radeon/radeon_video.c
+++ b/src/gallium/drivers/radeon/radeon_video.c
@@ -237,8 +237,9 @@ int rvid_get_video_param(struct pipe_screen *screen,
 		enum pipe_video_format codec = u_reduce_video_profile(profile);
 		switch (param) {
 		case PIPE_VIDEO_CAP_SUPPORTED:
 			/* no support for MPEG4 */
 			return codec != PIPE_VIDEO_FORMAT_MPEG4 &&
+			       codec != PIPE_VIDEO_FORMAT_HEVC &&
 			       /* FIXME: VC-1 simple/main profile is broken */
 			       profile != PIPE_VIDEO_PROFILE_VC1_SIMPLE &&
 			       profile != PIPE_VIDEO_PROFILE_VC1_MAIN;
@@ -237,8 +237,9 @@ int rvid_get_video_param(struct pipe_screen *screen,
 		switch (param) {
 		case PIPE_VIDEO_CAP_SUPPORTED:
-			/* no support for MPEG4 */
+			/* no support for MPEG4, HEVC */
 			return codec != PIPE_VIDEO_FORMAT_MPEG4 &&
-- 
1.8.3.1



More information about the mesa-stable mailing list